#!/usr/bin/env node
'use strict';

require('module-alias/register');
const commander = require('commander');

require('../lib/api/model').createCommand(commander);
require('../lib/api/skill').createCommand(commander);
require('../lib/api/vendor').createCommand(commander);
require('../lib/api/account-linking').createCommand(commander);
require('../lib/api/submission').createCommand(commander);
require('../lib/api/credentials').createCommand(commander);
require('../lib/api/skill-testing').createCommand(commander);
require('../lib/api/skill-validation').createCommand(commander);
require('../lib/api/private-skills').createCommand(commander);
require('../lib/api/enablement').createCommand(commander);
require('../lib/api/in-skill-product').createCommand(commander);
require('../lib/api/utterance-data').createCommand(commander);
require('../lib/api/catalog').createCommand(commander);
require('../lib/api/beta-test').createCommand(commander);
require('../lib/api/skill-accuracy').createCommand(commander);

commander
    .usage('\n\n  $ ask api [command]')
    .description('The api command provides a number of subcommands that enable you to create and modify skills associated with your developer account. There are subcommands for creating and updating the skill, interaction model, managing the in-skill products and account linking information as well as starting the skill certification process.')
    .parse(process.argv);

if (!process.argv.slice(2).length) {
    commander.outputHelp();
} else {
    const API_COMMAND_LIST = [
        'validate-skill',
        'get-validation',
        'simulate-skill',
        'get-simulation',
        'invoke-skill',
        'create-skill',
        'get-skill',
        'update-skill',
        'delete-skill',
        'get-model',
        'head-model',
        'update-model',
        'get-skill-status',
        'get-skill-credentials',
        'create-account-linking',
        'get-account-linking',
        'delete-account-linking',
        'list-skills',
        'list-vendors',
        'submit',
        'withdraw',
        'add-private-distribution-account',
        'delete-private-distribution-account',
        'list-private-distribution-accounts',
        'enable-skill',
        'disable-skill',
        'get-skill-enablement',
        'create-isp',
        'get-isp',
        'update-isp',
        'associate-isp',
        'disassociate-isp',
        'list-isp-for-vendor',
        'list-isp-for-skill',
        'list-skills-for-isp',
        'delete-isp',
        'reset-isp-entitlement',
        'intent-requests-history',
        'list-catalogs',
        'create-catalog',
        'get-catalog',
        'list-catalog-uploads',
        'get-catalog-upload',
        'associate-catalog-with-skill',
        'upload-catalog',
        'create-beta-test',
        'update-beta-test',
        'get-beta-test',
        'start-beta-test',
        'end-beta-test',
        'list-beta-testers',
        'add-beta-testers',
        'remove-beta-testers',
        'send-reminder-to-beta-testers',
        'request-feedback-from-beta-testers',
        'nlu-profile'
    ];
    if (API_COMMAND_LIST.indexOf(process.argv[2]) === -1) {
        console.log('Command not recognized. Please run "ask api" for help.');
    }
}
