const apiWrapper = require('./api-wrapper');
const tools = require('../utils/tools');
const profileHelper = require('../utils/profile-helper');
const optionValidator = require('../commands/option-validator');

// Public
module.exports = {
    createCommand: (commander) => {
        buildProfileNluCommand(commander);
    }
};

// Private
function buildProfileNluCommand(commander) {
    commander
        .command('nlu-profile')
        .usage('<-s|--skill-id <skill-id>> [-g|--stage <stage>] <-l|--locale <locale>>'
            + ' <-u|--utterance <utterance>> [-t|--multiturn-token <multiturn-token>]'
            + ' [-p|--profile <profile>] [--debug]')
        .option('-s, --skill-id <skill-id>', 'skill-id for the skill')
        .option('-g, --stage <stage>', 'skill stage (development or live). Defaults to development.')
        .option('-l, --locale <locale>', 'locale for the skill. Example: en-US.')
        .option('-u, --utterance <utterance>', 'utterance to be profiled')
        .option('-t, --multiturn-token <multiturn-token>', 'optional multiturn token for dialog')
        .option('-p, --profile <profile>', 'optional ask cli profile')
        .option('--debug', 'optional ask cli debug mode')
        .description('profile utterance with NLU')
        .action(handle);

    function handle(options) {
        try {
            optionValidator.validateSkillId(options.skillId);
            optionValidator.validateStage(options.stage, { required: false });
            optionValidator.validateUtterance(options.utterance);
            optionValidator.validateLocale(options.locale);
        } catch (err) {
            console.error(`[Error]: ${err}`);
            process.exit(1);
        }

        const profile = profileHelper.runtimeProfile(options.profile);
        apiWrapper.callProfileNlu(options.skillId, options.stage, options.locale, options.utterance,
            options.multiturnToken, profile, options.debug, (data) => {
                const response = tools.convertDataToJsonObject(data.body);
                if (response) {
                    console.log(JSON.stringify(response, null, 2));
                }
            });
    }
}
