const CONSTANTS = require('@src/utils/constants');

const EMPTY_HEADERS = {};
const EMPTY_QUERY_PARAMS = {};
const NULL_PAYLOAD = null;

module.exports = (smapiHandle) => {
    function getModel(skillId, stage, locale, callback) {
        const url = `skills/${skillId}/stages/${stage}/interactionModel/locales/${locale}`;
        smapiHandle(
            CONSTANTS.COMMAND.NAME.GET_MODEL,
            CONSTANTS.HTTP_REQUEST.VERB.GET,
            CONSTANTS.SMAPI.VERSION.V1,
            url,
            EMPTY_QUERY_PARAMS,
            EMPTY_HEADERS,
            NULL_PAYLOAD,
            callback
        );
    }

    function updateModel(skillId, stage, locale, modelSchema, eTag, callback) {
        const url = `skills/${skillId}/stages/${stage}/interactionModel/locales/${locale}`;
        const payload = {
            interactionModel: modelSchema.interactionModel
        };
        smapiHandle(
            CONSTANTS.COMMAND.NAME.UPDATE_MODEL,
            CONSTANTS.HTTP_REQUEST.VERB.PUT,
            CONSTANTS.SMAPI.VERSION.V1,
            url,
            EMPTY_QUERY_PARAMS,
            eTag ? { 'If-Match': eTag } : {},
            payload,
            callback
        );
    }

    function headModel(skillId, stage, locale, callback) {
        const url = `skills/${skillId}/stages/${stage}/interactionModel/locales/${locale}`;
        smapiHandle(
            CONSTANTS.COMMAND.NAME.HEAD_MODEL,
            CONSTANTS.HTTP_REQUEST.VERB.HEAD,
            CONSTANTS.SMAPI.VERSION.V1,
            url,
            EMPTY_QUERY_PARAMS,
            EMPTY_HEADERS,
            NULL_PAYLOAD,
            callback
        );
    }

    return {
        getModel,
        updateModel,
        headModel
    };
};
