const path = require('path');

const urlUtils = require('@src/utils/url-utils');
const jsonUtility = require('../utils/json-utility');
const domainRegistry = require('../utils/domain-registry');

module.exports = {
    localizing
};

function localizing(skillPath, lambdaResourcesList) {
    const skillJson = jsonUtility.read(skillPath);
    for (const lambdaInfo of lambdaResourcesList) {
        for (const usage of lambdaInfo.alexaUsage) {
            const domainKey = domainRegistry.getSkillSchemaKey(usage.split('/')[0]);
            const region = usage.split('/')[1];

            const skillJsonPropertyPathToUri = region !== 'default'
                ? ['manifest', 'apis', domainKey, 'regions', region, 'endpoint', 'uri']
                : ['manifest', 'apis', domainKey, 'endpoint', 'uri'];
            const uri = jsonUtility.getPropertyValueFromObject(skillJson, skillJsonPropertyPathToUri);
            if (!urlUtils.isLambdaArn(uri)) {
                continue;
            }
            // write sourceDir to skill.json sourceDir
            const skillJsonPropertyPathToSourceDir = region !== 'default'
                ? ['manifest', 'apis', domainKey, 'regions', region, 'endpoint', 'sourceDir']
                : ['manifest', 'apis', domainKey, 'endpoint', 'sourceDir'];
            const relativePath = `lambda${path.sep}${lambdaInfo.awsRegion}_${lambdaInfo.functionName}`;
            jsonUtility.insertObjectToObject(skillJson, skillJsonPropertyPathToSourceDir, relativePath);
            // wrte functionName to skill.json uri
            jsonUtility.insertObjectToObject(skillJson, skillJsonPropertyPathToUri, lambdaInfo.functionName);
        }
    }
    jsonUtility.write(skillPath, skillJson);
}
