const path = require('path');
const fs = require('fs-extra');
const jsonfile = require('jsonfile');

// Public
module.exports = {
    clone
};

function clone(newProjectRootPath, skillId, skillInfo, profile) {
    _createProjectDirectory(newProjectRootPath, skillInfo);
    _createDefaultConfigFile(path.join(newProjectRootPath, '.ask/config'), skillId, profile);
    console.log(`Project directory for ${skillInfo.skillName} created at
    ./${skillInfo.skillName}\n`);
}

// Private
function _createProjectDirectory(newProjectRootPath, skillInfo) {
    if (fs.existsSync(newProjectRootPath)) {
        console.warn('[Warn]: Project with same name existed. Project will be overwritten.\n');
        // TODO make an option to stop the process, and make a flag to enforce the process. so that the behaviour
        // will be: if someone uses the bash script, they can use clone with enforcing flag so prevent the promote
        // option. Otherwise, a promoter will pop out and ask a user whether to override the existing project or not.
        fs.removeSync(newProjectRootPath);
    }
    fs.mkdirSync(newProjectRootPath);

    const askConfigPath = path.join(newProjectRootPath, '.ask');
    if (!fs.existsSync(askConfigPath)) {
        fs.mkdirSync(askConfigPath);
    }

    if (skillInfo.domainList && skillInfo.domainList.indexOf('custom') !== -1) {
        const modelPath = path.join(newProjectRootPath, 'models');
        if (!fs.existsSync(modelPath)) {
            fs.mkdirSync(modelPath);
        }
    }

    if (skillInfo.hasLambdaFunction) {
        const lambdaPath = path.join(newProjectRootPath, 'lambda');
        if (!fs.existsSync(lambdaPath)) {
            fs.mkdirSync(lambdaPath);
        }
    }
}

function _createDefaultConfigFile(configPath, skillId, profile) {
    const config = {
        deploy_settings: {
            [profile]: {
                skill_id: skillId || '',
                was_cloned: true,
                merge: {}
            }
        }
    };
    jsonfile.writeFileSync(configPath, config, { spaces: 2 });
}
