const path = require('path');
const httpClient = require('@src/clients/http-client');
const tools = require('@src/utils/tools');
const gitClient = require('@src/clients/git-client');
const displayUtil = require('@src/utils/display-utility');
const urlUtils = require('@src/utils/url-utils');
const ui = require('./ui');

module.exports = {
    getTemplateMap,
    gitCloneTemplate
};

function getTemplateMap(templateUrl, doDebug, callback) {
    const params = {
        url: templateUrl,
        method: 'GET'
    };
    httpClient.request(params, 'getTemplateMap', doDebug, (error, response) => {
        if (error || response.statusCode === null || response.statusCode !== 200) {
            callback('[Error]: Cannot retrieve the template list.', null);
        } else {
            callback(null, tools.convertDataToJsonObject(response.body));
        }
    });
}

function gitCloneTemplate(cloneUrl, skillPackageName, callback) {
    const officialUrl = urlUtils.isUrlOfficialTemplate(cloneUrl);
    if (!officialUrl) {
        console.warn('[Warn]: Downloading skill template from unofficial resource. '
        + 'Please make sure you understand what each script is doing to best protect yourself from malicious usage');
        ui.getConfirmation((err, res) => {
            if (err) {
                callback(err);
            }
            if (!res) {
                process.exit(1);
            }
            _cloneTemplate(cloneUrl, skillPackageName, callback);
        });
    } else {
        _cloneTemplate(cloneUrl, skillPackageName, callback);
    }
}

// Private
function _cloneTemplate(cloneUrl, skillPackageName, callback) {
    const installSpinner = new displayUtil.Spinner(' Initializing Alexa skill project from the chosen template...');
    installSpinner.start();
    const cloneDir = path.join(process.cwd(), skillPackageName);
    gitClient.clone(cloneUrl, cloneDir, (err) => {
        installSpinner.stop();
        callback(err);
    });
}
