const inquirer = require('inquirer');
const CONSTANTS = require('@src/utils/constants');
const skillParser = require('@src/utils/skill-parser');

module.exports = {
    getSkillName,
    getRunTime,
    getTargetTemplateName,
    getConfirmation,
    getSkillSuggestion
};


function getSkillName(skillName, url, templateName, callback) {
    if (skillName) {
        process.nextTick(() => {
            callback(null, skillName.trim());
        });
    } else {
        const repoName = getSkillSuggestion(templateName, url);
        inquirer.prompt([{
            message: 'Please type in your skill name: ',
            type: 'input',
            default: repoName,
            name: 'skillName'
        }]).then((answer) => {
            callback(null, answer.skillName.trim());
        });
    }
}

function getRunTime(callback) {
    const runTimeChoiceQuestion = {
        type: 'list',
        message: 'Please select the runtime',
        name: 'runTime',
        choices: Object.keys(CONSTANTS.LAMBDA.RUNTIME)
    };
    inquirer.prompt([runTimeChoiceQuestion]).then((answer) => {
        callback(null, answer.runTime.trim());
    });
}


function getTargetTemplateName(templateList, inputName, callback) {
    if (inputName) {
        if (templateList.indexOf(inputName) === -1) {
            process.nextTick(() => {
                callback('[Error]: No template found with the input template name. '
                    + 'Please make sure the template list contains the one you want to use.');
            });
        } else {
            process.nextTick(() => {
                callback(null, inputName);
            });
        }
    } else {
        const templateChoiceQuestion = {
            type: 'list',
            message: 'List of templates you can choose',
            name: 'templateName',
            choices: templateList
        };
        inquirer.prompt([templateChoiceQuestion]).then((answer) => {
            callback(null, answer.templateName);
        });
    }
}

function getConfirmation(callback) {
    const confirmationQuestion = {
        message: 'Would you still like to continue execution ?',
        type: 'confirm',
        name: 'confirmation',
        default: false
    };
    inquirer.prompt([confirmationQuestion]).then((answer) => {
        callback(null, answer.confirmation);
    });
}

function getSkillSuggestion(templateName, url) {
    if (templateName) {
        return skillParser.filterUserSkillName(templateName.trim());
    }
    let repoName = null;
    if (url) {
        const repo = url.substring((url.lastIndexOf('/') + 1), url.lastIndexOf('.'));
        repoName = skillParser.filterUserSkillName(repo);
    }
    return repoName;
}
