const jsonUtility = require('../utils/json-utility');
const domainRegistry = require('../utils/domain-registry');

module.exports = {
    localizingCreatedLambdaARN
};

function localizingCreatedLambdaARN(createdLambdaList, projectConfigFile, skillFile, profile) {
    if (!createdLambdaList || createdLambdaList.length === 0) {
        return;
    }
    const projectConfig = jsonUtility.read(projectConfigFile);
    const skillManifest = jsonUtility.read(skillFile);
    createdLambdaList.forEach((metaData) => {
        for (const usage of metaData.alexaUsage) {
            const domain = domainRegistry.getSkillSchemaKey(usage.split('/')[0]);
            const region = usage.split('/')[1];

            // modify the uri to true arn only when uri exists originally in the merge field
            // skill.json remains function name for the feature of profile switching
            const mergePathToUrl = region === 'default' ? ['deploy_settings', profile, 'merge', 'manifest', 'apis', domain, 'endpoint', 'uri']
                : ['deploy_settings', profile, 'merge', 'manifest', 'apis', domain, 'regions', region, 'endpoint', 'uri'];
            if (jsonUtility.getPropertyValueFromObject(projectConfig, mergePathToUrl)) {
                jsonUtility.insertObjectToObject(projectConfig, mergePathToUrl, metaData.arn);
            }
        }
    });
    jsonUtility.write(projectConfigFile, projectConfig);
    jsonUtility.write(skillFile, skillManifest);
}
