'use strict';
const jsonUtility = require('../utils/json-utility');

module.exports = {
    getJsonInputAndOutputs: getJsonInputAndOutputs,
    isSkillResponseSessionEnd: isSkillResponseSessionEnd,
    getConsideredIntents: getConsideredIntents
};

function getConsideredIntents(response) {
    const consideredIntents = jsonUtility.getPropertyValueFromObject(
        response, ['result', 'alexaExecutionInfo', 'consideredIntents']);
    if (!consideredIntents) {
        return [];
    } 

    return consideredIntents;
}

function getJsonInputAndOutputs(response) {
    const invocations = jsonUtility.getPropertyValueFromObject(
        response, ['result', 'skillExecutionInfo', 'invocations']
    );

    if (!invocations) {
        return [];
    }

    let jsonInputs = invocations.map(invocation => {
        const invocationRequest = jsonUtility.getPropertyValueFromObject(invocation, ['invocationRequest', 'body']);
        return invocationRequest ? invocationRequest : { };
    });

    let jsonOutputs = invocations.map(invocation => {
        const invocationResponse = jsonUtility.getPropertyValueFromObject(invocation, ['invocationResponse']);
        return invocationResponse ? invocationResponse : { };
    });

    const result = [];
    for (let i = 0; i < jsonInputs.length; i++) {
        const io = {
            jsonInput: jsonInputs[i],
            jsonOutput: i < jsonOutputs.length ? jsonOutputs[i] : { }
        };
        result.push(io);
    }

    return result;
}

function isSkillResponseSessionEnd(response) {
    const invocations = jsonUtility.getPropertyValueFromObject(
        response, ['result', 'skillExecutionInfo', 'invocations']
    );

    if (!invocations) {
        return false;
    }

    for (let invocation of invocations) {
        if (jsonUtility.getPropertyValueFromObject(invocation, 
            ['invocationResponse', 'body', 'response', 'shouldEndSession'])) {
            return true;
        }
    }
    
    return false;
}
