'use strict';

const profileHelper = require('../utils/profile-helper');
const constants = require('../utils/constants');
const ispUtil = require('../utils/isp-utils/isp-utility');
const ispConstants = require('../utils/isp-utils/isp-constants');
const showISPStatus = require('../resource/isp').showISPStatus;

module.exports = {
    createCommand: (commander) => {
        commander
            .command('status')
            .description('show the status of the skill resources')
            .option('--isp', 'show the status of the in-skill products')
            .option('-p, --profile <profile>', 'ask cli profile')
            .option('-h, --help', 'output usage information', () => {
                console.log(constants.COMMAND.STATUS.HELP_DESCRIPTION);
                process.exit(0);
            })
            .action(handle);

        function handle(options) {
            if (typeof options === 'string') {
                console.warn(constants.COMMAND.STATUS.HELP_DESCRIPTION);
                return;
            }

            let profile = profileHelper.runtimeProfile(options.profile);
            let skillProjectPath = process.cwd();

            if (options.isp) {
                /**
                 * Should only perform this commend under the skill product root directory
                 */
                if (!ispUtil.isAtSkillRoot()) {
                    console.error(ispUtil.getFormattedErrorString(ispConstants.ERROR.NOT_AT_SKILL_PROJECT_ROOT));
                    return;
                }
                showISPStatus(skillProjectPath, profile);
            } else {
                console.warn(constants.COMMAND.STATUS.HELP_DESCRIPTION);
            }
        }
    }
};
