'use strict';

const fs = require('fs');
const path = require('path');

module.exports = {
    readTestersFromFile: readTestersFromFile,
    validateFile: validateFile
};

/**
 * Returns a list of tester object from file path
 * 
 * @param filePath path to the file contains tester email id list
 * @return {Array} list of tester object containing email id
 */
function readTestersFromFile(filePath) {
    const testers = [];
    fs.readFileSync(filePath).toString()
        .split('\n')
        .forEach((line, index, arr) => {
            // ignore header
            if (index !== 0) {
                const values = line.trim().split(',');
                if (!values.isEmpty) {
                    // take the first column as tester email id
                    testers.push({emailId: values[0].trim()});
                }
            }
        });
    return testers;
}

/**
 * Validates file parameter, existence, extension
 * 
 * @param filePath
 */
function validateFile(filePath) {
    if (!filePath) {
        console.warn('Please input required parameter: file.');
        process.exit(1);
    }

    if (!fs.existsSync(filePath)) {
        console.warn('Please verify the file path does exist.');
        process.exit(1);
    }

    if (!isSupportedFile(filePath)) {
        console.warn('The file extension is not supported.');
        process.exit(1);
    }
}

function isSupportedFile(filePath) {
    return path.extname(filePath) === '.csv';
}
