'use strict';

const CluiSpinner = require('clui').Spinner;
const clc = require('cli-color');

module.exports = {
    Spinner: Spinner,
    printTable: printTable
};

/**
 * Get a Spinner that is friendly to OS other than Mac and Win
 * @param message
 * @returns {helpers.Spinner}
 */
function Spinner(message) {
    if (process.platform !== 'darwin') {
        return new CluiSpinner(message, ['/', '-', '\\', '|']);
    }
    return new CluiSpinner(message);
}

/**
 * Print table using given table headers and rows
 * @param tableHeaders array that defines the table headers
 * @param tableRows array that contains information for each rows
 */
function printTable(tableHeaders, tableRows) {
    if (!tableHeaders || !tableRows || tableHeaders.length === 0 || tableRows.length === 0) {
        return;
    }
    let displayRows = [];
    displayRows.push(tableHeaders);
    displayRows.push.apply(displayRows,tableRows);
    process.stdout.write(clc.columns(displayRows));
}
