const initAWS = require('@src/utils/init-aws');
const urlUtils = require('@src/utils/url-utils');

module.exports = {
    retrieveLambdaFunction,
    retrieveLambdaRuntime,
    getLambdaFunction
};

function retrieveLambdaFunction(functionName, awsRegion, awsProfile, callback) {
    const aws = initAWS.initAWS(awsProfile);
    if (!aws) {
        return;
    }
    getLambdaFunction(aws, functionName, awsRegion, (err, data) => {
        if (err) {
            // callback without error since lambda not exist
            if (err.code === 'ResourceNotFoundException') {
                callback();
            } else {
                callback(err, null);
            }
        } else {
            callback(null, data);
        }
    });
}

function retrieveLambdaRuntime(functionName, awsRegion, awsProfile, callback) {
    const aws = initAWS.initAWS(awsProfile);
    if (!aws) {
        callback('[Error]: Failed to initialize aws client.', null);
    }
    getLambdaFunction(aws, functionName, awsRegion, (err, data) => {
        callback(err, !err ? data.Configuration.Runtime : null);
    });
}

// Private
function getLambdaFunction(aws, functionName, region, callback) {
    const params = {
        FunctionName: functionName
    };
    const lambdaClient = new aws.Lambda({ region });
    lambdaClient.getFunction(params, (err, data) => {
        callback(err, data);
    });
}
