'use strict';

const expect = require('chai').expect;
const util = require('util');
const constants = require('./utils/constants');
const cliWrapper = require('./utils/cli-wrapper');
const responseParser = require('./utils/response-parser');
const message = require('./utils/messages');
const fs = require("fs");
const TIMEOUT = 80000;
const SKILL_FILE = './test/functional/fixture/custom-skill/skill.json';
const INVALID_FILE_PATH = './test/functional/fixture/custom-skill';
let skillId;

describe('create skill tests', function () {
    this.timeout(TIMEOUT);
    it('| create skill with valid file', (done) => {
        cliWrapper.callCreateSkill(SKILL_FILE, constants.testData.PROFILE, (error, stdout, stderr) => {
            if (error) {
                done(error);
            } else {
                skillId = responseParser.getSkillID(stdout);
                expect(stdout.startsWith(message.CREATE_SKILL_SUBMITED)).equal(true);
                //check exit code should be 0
                done();
            }
        });
    });

    it('| create skill with invalid file path', (done) => {
        cliWrapper.callCreateSkill(INVALID_FILE_PATH, constants.testData.PROFILE, (error, stdout, stderr) => {
            expect(error);
            expect(stderr.startsWith(message.INVALID_FILE_PATH_MSG) > -1).equal(true);
            //BUG: exit code should be 1 now is 0
            done();
        });
    });

    it('| create skill with invalid profile', (done) => {
        cliWrapper.callCreateSkill(SKILL_FILE, constants.testData.INVALID_PROFILE, (error, stdout, stderr) => {
            expect(error);
            let errorMessage = util.format(message.INVALID_PROFILE_MSG, constants.INVALID_PROFILE);
            expect(stderr.startsWith(errorMessage) > -1).equal(true);
            //exit code should be 1
            done();
        });
    });

    after('tear down', (done) => {
        this.timeout(TIMEOUT);
        if (!skillId) {
            console.log('Create skill fail, skip delete skill operation');
            done();
        } else {
            cliWrapper.callDeleteSkill(skillId, constants.testData.PROFILE, (error, stdout, stderr) => {
                if (error) {
                    console.log(`Failed to delete ${skillId} when cleaning test data. Error: ${error}`);
                    done(error);
                } else {
                    expect(stdout).equal(message.DELETE_SKILL);
                    // exit code should be 0
                    done();
                }
            });
        }
    });
});