'use strict';
const constants = require('./constants');
const child_process = require('child_process');

module.exports = {
    askCommandRunner: askCommandRunner,
    runApiCommand: runApiCommand,
    executeCommand: executeCommand
};

/**
 * This is a private function that will execute any command 
 * which is given to the command prompt.
 * @param {String} cmd command to execute
 * @param {*} callback 
 */
function executeCommand(cmd, callback) {
    child_process.exec(cmd, (err, stdout, stderr) => {
        callback(err, stdout, stderr);
    });
}

/**
 * execute ask command to into the command line.
 * @param {String} cmdName hight command Name ex: new, deploy, clone, simulate
 * @param {Object} optionsMap prameters within the command
 * @param {*} callback 
 */
function askCommandRunner(cmdName, optionsMap, callback) {
    let subfix = '';
    for (let key of Object.keys(optionsMap)) {
        if (optionsMap[key]) {
            subfix += `${key}  ${optionsMap[key]} `;
        }
    }
    executeCommand(constants.hightLevel.ASK_PREFIX + cmdName + subfix, callback);
}

/**
 * execute ask api command into the command line.
 * @param {String} apiName any of the low level command name ex: get-model, get-skill
 * @param {Object} optionsMap prameters within the command
 * @param {*} callback 
 */
function runApiCommand(apiName, optionsMap, callback) {
    const apiSubCommand = constants.hightLevel.API + apiName;
    askCommandRunner(apiSubCommand, optionsMap, callback);
}
