'use strict';

const expect = require('chai').expect; 
const git = require('simple-git');
const sinon = require('sinon');
const proxyquire = require('proxyquire');
const gitClient = require('@src/clients/git-client');

describe('Clients test - cli git client', () => {

    describe('# git clone check', () => {
        const TEST_CLONE_DIR = 'testCloneDir';
        const TEST_CLONE_URL = 'https://test.git';
        const TEST_ERROR = 'testError';
     
        it('| git clone a repo fails, returns error', () => {
            // setup
            let proxygitClient;
            const cloneStub = sinon.stub();
            proxygitClient = proxyquire('@src/clients/git-client', {
                'simple-git': () => {
                    return { 
                        silent: () => {
                            return {
                                clone: cloneStub
                            };
                        }
                    };
                }
            });
            cloneStub.callsArgOnWith(2, {}, TEST_ERROR);
    
            // call
            proxygitClient.clone(TEST_CLONE_URL, TEST_CLONE_DIR, (err) => {
                expect(err).to.equal(TEST_ERROR);
            });
            // verify
            expect(cloneStub.args[0][0]).to.equal(TEST_CLONE_URL);
            expect(cloneStub.args[0][1]).to.equal(TEST_CLONE_DIR);
        });
    });
});