'use strict';

const chai = require('chai');
const expect = chai.expect;
const sinon = require('sinon');
const apiWrapper = require('../../../lib/api/api-wrapper.js');
const displayUtil = require('../../../lib/utils/display-utility');
const sender = require('../../../lib/dialog/simulation-sender');

describe('dialog command simulation sender testing', () => {
    describe('# test polling get simulation result', () => {
        let sandbox;
        let inputTextArray;
        let mockSpinner;
        const TEST_STAGE = 'stage';

        before(() => {
            mockSpinner = displayUtil.Spinner();
        });

        beforeEach(() => {
            sandbox = sinon.sandbox.create();
            sandbox.stub(process, 'exit');
            inputTextArray = [];
            sandbox.stub(displayUtil, 'Spinner').callsFake(() => {
                return mockSpinner;
            });
        });
        afterEach(() => {
            sandbox.restore();
        });

        it ('| add text in array polling response is FAILED', () => {
            sandbox.stub(console, 'error');
            sandbox.stub(apiWrapper, 'callSimulateSkill')
                   .callsArgWith(8, {"body": {"id": 6789, "status": "IN_PROGRESS"}});

            sandbox.stub(apiWrapper, 'callGetSimulation')
                   .callsArgWith(5, {"body": {"id": 6789, "status": "FAILED", "result" : {"error": {"message": "test error"}}}});
            let clock = sandbox.useFakeTimers();

            sender.sendDialogSimulate('text', 'skillId', 'en-US', false, null, inputTextArray, TEST_STAGE, 'default', false);

            clock.tick(1001);

            expect(inputTextArray[0]).equal('text');
        });

        it ('| add text in array when the polling response is SUCCESSFUL', () => {
            sandbox.stub(apiWrapper, 'callSimulateSkill')
                   .callsArgWith(8, {"body": {"id": 6789, "status": "IN_PROGRESS"}});

            sandbox.stub(apiWrapper, 'callGetSimulation')
                   .callsArgWith(5, {"body": {"id": 6789, "status": "SUCCESSFUL", "result" : {"alexaExecutionInfo": {"alexaResponses": [{"content": {"caption": "testCaption"}}, {"content": {"caption": "testCaption2"}}]}}}});
            let clock = sandbox.useFakeTimers();

            sandbox.stub(console, 'log');
            sender.sendDialogSimulate('text', 'skillId', 'en-US', false, null, inputTextArray, TEST_STAGE, 'default', false);

            clock.tick(1001);

            expect(inputTextArray[0]).equal('text');
            console.log.restore();
        });
    });
});

